add_dates: helper function to add dates to the projected time points

Description Usage Arguments

View source: R/short_term.R

Description

helper function to add dates to the projected time points

Usage

1
add_dates(df, date, look_ahead)

Arguments

df

model output df

date

sys.date()

look_ahead

number of days to forecast: default is 14


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.