backtest_short: function to backtest model parameters.

Description Usage Arguments

View source: R/backtest.R

Description

compare model forecasts to the efficient market hypothesis (i.e. assuming share price is the same the next day as it was the previous day)

Usage

1
backtest_short(ticker, n_tests, ncores, vendor = "quandl", ...)

Arguments

ticker

which ticker or tickers should we evaluate?

n_tests

how many tests per ticker per month of data should we use?

ncores

number of cores to use for parallel computing.

...

additional parameters passed to renarin_short_historic


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.