clean_fundamentals: internal function to help process fundamentals data

Description Usage Arguments

View source: R/create_reference.R

Description

This is filtering out non-quarterly reports and adjusted reports, limiting to a certain year or range of years, and

Usage

1

Arguments

df

data frame

year

year or range of years to create the reference database from. good idea to choose range with similar macroeconomic conditions to current economy.


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.