create_reference: wrapper around tidyquant functions to create a reference...

Description Usage Arguments Value

View source: R/create_reference.R

Description

was going to set this up entirely via API but turns out the easiest way to do this by far is to download the full tables via batch download and start from there

Usage

1
2
3
4
5
6
create_reference(
  vendor = "quandl",
  ncores = 4,
  data_repo = "G:/My Drive/pkg/data/sharadar/",
  year = 2018
)

Arguments

vendor

which data warehouse - currently only works with the Sharadar tables from quandl

ncores

number of cores to utilize for data processing and ingestion

data_repo

filepath where function can find the Sharadar/SF1 table,

year

year or range of years to create the reference database from. good idea to choose range with similar macroeconomic conditions to current economy.

Value

tibble containing time series data for our analysis.


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.