helper function for backtest_short - this function only works with the Sharadar data feed.
1 | get_times(ticker, n_tests, vendor)
|
ticker |
which ticker or tickers should we evaluate? |
n_tests |
how many tests per ticker per month of data should we use? |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.