process_fit: helper function to process and join forecast output from...

Description Usage Arguments

View source: R/short_term.R

Description

helper function to process and join forecast output from renarin_short

Usage

1
process_fit(fit, fcast, df, look_ahead, PI)

Arguments

fit

model fit object (from nnetar)

fcast

model forecast object

df

model_df

look_ahead

how many days did we forecast? inherits from renarin_short


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.