use nnet forecasting to evaluate future stock price.
1 2 3 4 5 6 7 8 9 10 | renarin_short(
ticker,
vendor = "yahoo",
look_back = 200,
look_ahead = 14,
lag = 10,
decay = 0.2,
zoom_in = TRUE,
PI = FALSE
)
|
ticker |
security name, e.g. AAPL |
vendor |
provider for data: leave at yahoo unless you have paid for the quandl sharadar equity prices data feed. |
look_back |
number of days to look back for predictions: default is 200 |
look_ahead |
number of days to forecast: default is 14 |
lag |
number of days to use to fit the next day in the model |
decay |
NNET parametar |
zoom_in |
should function return full model and forecast results? useful for highlighting speicific issues |
PI |
logical: should we compute prediction intervals?: under development |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.