renarin_short_historic: function to generate forecast for a given ticker (using...

Description Usage Arguments

View source: R/short_term_historic.R

Description

use nnet forecasting to evaluate future stock price.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
renarin_short_historic(
  date = NULL,
  ticker,
  look_back = 200,
  look_ahead = 14,
  zoom_in = FALSE,
  lag = 20,
  decay = 0.2,
  vendor = "quandl",
  PI = FALSE
)

Arguments

date

if most recent == FALSE, what date should we project from?

ticker

security name, e.g. AAPL

look_back

number of days to look back for predictions

look_ahead

number of days to forecast

zoom_in

should function return full model and forecast results? useful for highlighting speicific issues

lag

number of days to use to fit the next day in the model

decay

NNET parametar

df

if most_recent = FALSE, provide historical pricing dataframe


DavisWeaver/stonkr_public documentation built on March 18, 2021, 2:35 p.m.