compare model forecasts to the efficient market hypothesis (i.e. assuming share price is the same the next day as it was the previous day)
1 | backtest_short(ticker, n_tests, ncores, vendor = "quandl", ...)
|
ticker |
which ticker or tickers should we evaluate? |
n_tests |
how many tests per ticker per month of data should we use? |
ncores |
number of cores to use for parallel computing. |
... |
additional parameters passed to renarin_short_historic |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.