View source: R/create_reference.R
This is filtering out non-quarterly reports and adjusted reports, limiting to a certain year or range of years, and
1 | clean_fundamentals(df, year)
|
df |
data frame |
year |
year or range of years to create the reference database from. good idea to choose range with similar macroeconomic conditions to current economy. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.