Description Usage Arguments Value
View source: R/create_reference.R
was going to set this up entirely via API but turns out the easiest way to do this by far is to download the full tables via batch download and start from there
1 2 3 4 5 6 | create_reference(
vendor = "quandl",
ncores = 4,
data_repo = "G:/My Drive/pkg/data/sharadar/",
year = 2018
)
|
vendor |
which data warehouse - currently only works with the Sharadar tables from quandl |
ncores |
number of cores to utilize for data processing and ingestion |
data_repo |
filepath where function can find the Sharadar/SF1 table, |
year |
year or range of years to create the reference database from. good idea to choose range with similar macroeconomic conditions to current economy. |
tibble containing time series data for our analysis.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.