View source: R/short_term_historic.R
use nnet forecasting to evaluate future stock price.
1 2 3 4 5 6 7 8 9 10 11 |
date |
if most recent == FALSE, what date should we project from? |
ticker |
security name, e.g. AAPL |
look_back |
number of days to look back for predictions |
look_ahead |
number of days to forecast |
zoom_in |
should function return full model and forecast results? useful for highlighting speicific issues |
lag |
number of days to use to fit the next day in the model |
decay |
NNET parametar |
df |
if most_recent = FALSE, provide historical pricing dataframe |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.